@@ -1,11 +1,12 @@
 "dat2bernqua" <-
 function(f, x, bern.control=NULL,
-               poly.type=c("Bernstein", "Kantorovich", "Cheng", "Parzen"),
-               bound.type=c("none", "sd", "Carv", "either"),
+               poly.type=c("Bernstein", "Kantorovich", "Cheng", "Parzen",
+                           "bernstein", "kantorovich", "cheng", "parzen"),
+               bound.type=c("none", "sd", "Carv", "either", "carv"),
                fix.lower=NULL, fix.upper=NULL, p=0.05, listem=FALSE) {
 
     poly.type <- match.arg(poly.type)
-    if(poly.type == "Parzen") {
+    if(poly.type == "Parzen" | poly.type == "parzen") {
        f <- 0.5 # just an arbitrary value to bypass the check.fs
        # The Parzen method uses its own specific definition of the f values
     }
@@ -44,12 +45,12 @@ function(f, x, bern.control=NULL,
     Carv.lower <- x[1] - (x[2] - x[1])/a
     Carv.upper <- x[n] + (x[n] - x[(n-1)])/a
 
-    if(poly.type == "Parzen") {
+    if(poly.type == "Parzen" | poly.type == "parzen") {
        fix.lower <- ifelse(is.null(fix.lower), x[1], fix.lower)
        fix.lower <- min(fix.lower, x[1])
        x[n+1] <- fix.lower; x <- sort(x)
        u <- sapply(1:n, function(r) { return((r-1)/n) })
-       qua <- sapply(1:n, function(r) { A <- (n*((r/n) - u[r]))*x[(r-1)+1]; B <- n*(u[r] - (r-1)/n)*x[(r+1)]; return(A+B) }) 
+       qua <- sapply(1:n, function(r) { A <- (n*((r/n) - u[r]))*x[(r-1)+1]; B <- n*(u[r] - (r-1)/n)*x[(r+1)]; return(A+B) })
        return(list(f=u, x=qua))
     }
 
@@ -57,7 +58,7 @@ function(f, x, bern.control=NULL,
         #message("Using the standard deviation support if either end is larger (smaller) than the respective data minimum (maximum)")
         fix.lower <- max(c(sd.lower, fix.lower))
         fix.upper <- min(c(sd.upper, fix.upper))
-    } else if(bound.type == "Carv") {
+    } else if(bound.type == "Carv" | bound.type == "carv") {
         #message("Using the de Carvalho support if either end is larger (smaller) than the respective data minimum (maximum)")
         fix.lower <- max(c(Carv.lower, fix.lower))
         fix.upper <- min(c(Carv.upper, fix.upper))
@@ -76,20 +77,20 @@ function(f, x, bern.control=NULL,
     for(i in 1:length(f)) {
        myf  <- log(f[i]);     if(! is.finite(myf))  myf  <- 0
        myfc <- log(1 - f[i]); if(! is.finite(myfc)) myfc <- 0
-       if(poly.type == "Cheng") {
+       if(poly.type == "Cheng" | poly.type == "cheng") {
              tmp <- sapply(1:n, function(k) {
                         xk <- x[k]
                         return(xk * exp(lchoose(n-1,k-1) + (k-1)*myf + (n-k)*myfc)) })
              qua[i] <- sum(tmp)
        } else {
-          if(poly.type == "Bernstein") {
+          if(poly.type == "Bernstein" | poly.type == "bernstein") {
              tmp <- sapply(0:(n+1), function(k) {
                         xk <- x[k]
                         if(k ==     0) xk <- fix.lower
                         if(k == (n+1)) xk <- fix.upper
                         return(xk * exp(lchoose(n+1,k) + k*myf + (n+1-k)*myfc)) })
              qua[i] <- sum(tmp)
-          } else if(poly.type == "Kantorovich") {
+          } else if(poly.type == "Kantorovich" | poly.type == "kantorovich") {
              tmp <- sapply(0:n, function(k) {
                         xk   <- ifelse(k == 0, fix.lower, x[k]  )
                         xkp1 <- ifelse(k == n, fix.upper, x[k+1])
