@@ -1,6 +1,6 @@
 "parwei" <-
 function(lmom,checklmom=TRUE,...) {
-    para <- vector(mode="numeric", length=3)
+    para <- rep(NA,3)
     names(para) <- c("zeta","beta","delta")
 
     if(length(lmom$L1) == 0) { # convert to named L-moments
@@ -10,7 +10,7 @@ function(lmom,checklmom=TRUE,...) {
     if(checklmom & ! are.lmom.valid(lmom)) {
       warning("L-moments are invalid")
       return()
-    } 
+    }
 
     lmom$L1   <- -lmom$L1
     lmom$LCV  <- -lmom$LCV
@@ -18,10 +18,10 @@ function(lmom,checklmom=TRUE,...) {
     lmom$L3   <- -lmom$L3
 
     par.gev <- pargev(lmom)
-    
+
     para[3] <- 1/par.gev$para[3]
     para[2] <- par.gev$para[2]*para[3]
     para[1] <- par.gev$para[1]+para[2]
-    return(list(type = 'wei', para=para, source="parwei")) 
+    return(list(type = 'wei', para=para, source="parwei"))
 }
 
